aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorDaniel Stenberg <daniel@haxx.se>2007-03-18 22:37:23 +0000
committerDaniel Stenberg <daniel@haxx.se>2007-03-18 22:37:23 +0000
commitff314d7600d1da0359dbf0dc84c747a345ce68e0 (patch)
treecdf8a3090e8e34818e0724722489aa81ddc02906 /tests
parentd052e545af336ec1d5142e1eeec5acc35dec21e2 (diff)
detect and show if built with yassl, but also set the "openssl" flag internally
since that is the API yassl attempts to provide
Diffstat (limited to 'tests')
-rwxr-xr-xtests/runtests.pl24
1 files changed, 16 insertions, 8 deletions
diff --git a/tests/runtests.pl b/tests/runtests.pl
index ca43309ca..56ed7816f 100755
--- a/tests/runtests.pl
+++ b/tests/runtests.pl
@@ -141,9 +141,13 @@ my $has_ipv6; # set if libcurl is built with IPv6 support
my $has_libz; # set if libcurl is built with libz support
my $has_getrlimit; # set if system has getrlimit()
my $has_ntlm; # set if libcurl is built with NTLM support
-my $has_openssl; # set if libcurl is built with OpenSSL
-my $has_gnutls; # set if libcurl is built with GnuTLS
-my $has_nss; # set if libcurl is built with NSS
+
+my $has_openssl; # built with a lib using an OpenSSL-like API
+my $has_gnutls; # built with GnuTLS
+my $has_nss; # built with NSS
+my $has_yassl; # built with yassl
+
+my $ssllib; # name of the lib we use (for human presentation)
my $has_crypto; # set if libcurl is built with cryptographic support
my $has_textaware; # set if running on a system that has a text mode concept
# on files. Windows for example
@@ -1010,16 +1014,21 @@ sub checksystem {
chomp($pwd = `cygpath -m $pwd`);
}
elsif ($libcurl =~ /openssl/i) {
- # OpenSSL in use
$has_openssl=1;
+ $ssllib="OpenSSL";
}
elsif ($libcurl =~ /gnutls/i) {
- # GnuTLS in use
$has_gnutls=1;
+ $ssllib="GnuTLS";
}
elsif ($libcurl =~ /nss/i) {
- # NSS in use
$has_nss=1;
+ $ssllib="NSS";
+ }
+ elsif ($libcurl =~ /yassl/i) {
+ $has_yassl=1;
+ $has_openssl=1;
+ $ssllib="yassl";
}
}
elsif($_ =~ /^Protocols: (.*)/i) {
@@ -1160,8 +1169,7 @@ sub checksystem {
}
if($ssl_version) {
- logmsg sprintf("* SSL library: %s\n",
- $has_gnutls?"GnuTLS":($has_openssl?"OpenSSL":($has_nss?"NSS":"<unknown>")));
+ logmsg sprintf("* SSL library: %s\n", $ssllib?"yassl":"<unknown>");
}
$has_textaware = ($^O eq 'MSWin32') || ($^O eq 'msys');